==> cxxtools_2.1.1.orig.tar.gz: cxxtools-2.1.1/src/http/request.cpp <==
/*
 * Copyright (C) 2009 by Tommi Maekitalo
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <cxxtools/http/request.h>
#include <cxxtools/textstream.h>
#include <cxxtools/base64codec.h>
#include <string>

namespace cxxtools {

namespace http {

Request::Auth Request::auth() const
{
    Auth ret;

    std::string s = getHeader("Authorization");
    std::string::size_type p = s.find(' ');
    if (p == std::string::npos)
        return ret;

    std::istringstream in(s);
    in.ignore(p + 1);

    cxxtools::BasicTextIStream<char, char> b(in, new cxxtools::Base64Codec());
    std::getline(b, ret.user, ':');
    std::getline(b, ret.password);

    return ret;
}

}

}

==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/src/http/request.cpp <==
/*
 * Copyright (C) 2009 by Tommi Maekitalo
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <cxxtools/http/request.h>
#include <cxxtools/textstream.h>
#include <cxxtools/base64codec.h>
#include <string>

namespace cxxtools {

namespace http {

Request::Auth Request::auth() const
{
    Auth ret;

    const char* sp = getHeader("Authorization");
    if (!sp)
        return ret;

    std::string s = sp;
    std::string::size_type p = s.find(' ');
    if (p == std::string::npos)
        return ret;

    std::istringstream in(s);
    in.ignore(p + 1);

    cxxtools::BasicTextIStream<char, char> b(in, new cxxtools::Base64Codec());
    std::getline(b, ret.user, ':');
    std::getline(b, ret.password);

    return ret;
}

}

}
